@@ -15,6 +15,8 @@ from collections.abc import (
 from contextlib import asynccontextmanager, contextmanager
 import contextvars as cv
 import datetime
+from enum import IntEnum
+from functools import lru_cache, partial, wraps
 from itertools import chain, compress, filterfalse, repeat, starmap, takewhile
 import json
 from pathlib import Path, PurePath
@@ -27,7 +29,7 @@ from loguru import logger
 import sqlalchemy as sa
 import sqlalchemy.exc as sa_exc
 import sqlalchemy.future as sa_future
-from typing_extensions import Literal, TypeAlias, TypedDict
+from typing_extensions import Concatenate, Literal, ParamSpec, TypeAlias, TypedDict
 from yarl import URL
 
 from . import _deferred_types, db, models
@@ -66,13 +68,14 @@ if TYPE_CHECKING:  # pragma: no cover
 else:
     _BaseResolverDict = dict
 
+_P = ParamSpec('_P')
 _T = TypeVar('_T')
-_C = TypeVar('_C', bound='Callable[..., Awaitable[object]]')
+_CManager: TypeAlias = 'Callable[Concatenate[Manager, _P], Awaitable[_T]]'
 
 
 USER_AGENT = 'instawow (https://github.com/layday/instawow)'
 
-DB_REVISION = '9b8df9661cdb'
+DB_REVISION = '75f69831f74f'
 
 
 class _GenericDownloadTraceRequestCtx(TypedDict):
@@ -183,30 +186,34 @@ async def cache_response(
     return json.loads(text) if is_json else text
 
 
-def prepare_database(config: Config) -> sa_future.Engine:
-    engine = sa.create_engine(
-        f'sqlite:///{config.db_file}',
-        # We wanna be able to operate on SQLite objects from executor threads
-        # for convenience, when performing disk I/O
-        connect_args={'check_same_thread': False},
-        # echo=True,
-        future=True,
-    )
+class DatabaseState(IntEnum):
+    current = 0
+    old = 1
+    uninitialised = 2
 
+
+def get_database_state(engine: sa_future.Engine) -> DatabaseState:
     with engine.connect() as connection:
         try:
-            current = connection.execute(
+            state = connection.execute(
                 sa.text(
-                    'SELECT version_num FROM alembic_version WHERE version_num = :version_num'
+                    'SELECT ifnull((SELECT 0 FROM alembic_version WHERE version_num == :version_num), 1)',
                 ),
                 {'version_num': DB_REVISION},
             ).scalar()
         except sa_exc.OperationalError:
-            should_migrate = True
-        else:
-            should_migrate = not current
+            state = connection.execute(
+                sa.text(
+                    'SELECT ifnull((SELECT 1 FROM sqlite_master WHERE type = "table" LIMIT 1), 2)',
+                )
+            ).scalar()
 
-    if should_migrate:
+    return DatabaseState(state)
+
+
+def migrate_database(engine: sa_future.Engine) -> None:
+    should_migrate = get_database_state(engine)
+    if should_migrate != DatabaseState.current:
         import alembic.command
         import alembic.config
 
@@ -214,34 +221,53 @@ def prepare_database(config: Config) -> sa_future.Engine:
         alembic_config.set_main_option('script_location', f'{__package__}:migrations')
         alembic_config.set_main_option('sqlalchemy.url', str(engine.url))
 
-        if sa.inspect(engine).get_table_names():
-            alembic.command.upgrade(alembic_config, DB_REVISION)
-        else:
+        if should_migrate == DatabaseState.uninitialised:
             db.metadata.create_all(engine)
             alembic.command.stamp(alembic_config, DB_REVISION)
+        else:
+            alembic.command.upgrade(alembic_config, DB_REVISION)
 
+
+def prepare_database(config: Config) -> sa_future.Engine:
+    engine = sa.create_engine(
+        f'sqlite:///{config.db_file}',
+        # We wanna be able to operate on the database from executor threads
+        # when performing disk I/O
+        connect_args={'check_same_thread': False},
+        # echo=True,
+        future=True,
+    )
+    migrate_database(engine)
     return engine
 
 
+@lru_cache(None)
+def _load_certifi_certs():
+    try:
+        import certifi
+    except ModuleNotFoundError:
+        pass
+    else:
+        from importlib.resources import read_text
+
+        logger.info('loading certifi certs')
+        return read_text(certifi, 'cacert.pem', encoding='ascii')
+
+
 def init_web_client(**kwargs: Any) -> _deferred_types.aiohttp.ClientSession:
     from aiohttp import ClientSession, ClientTimeout, TCPConnector
 
-    try:
-        import certifi
-    except ModuleNotFoundError:
-        connector = TCPConnector(force_close=True, limit_per_host=10)
-    else:
-        from importlib.resources import read_text
+    make_connector = partial(TCPConnector, force_close=True, limit_per_host=10)
+    certifi_certs = _load_certifi_certs()
+    if certifi_certs:
         import ssl
 
-        logger.info('loading certifi certs')
-        ssl_context = ssl.create_default_context(
-            cadata=read_text(certifi, 'cacert.pem', encoding='ascii')
+        make_connector = partial(
+            make_connector, ssl=ssl.create_default_context(cadata=certifi_certs)
         )
-        connector = TCPConnector(force_close=True, limit_per_host=10, ssl=ssl_context)
 
     kwargs = {
-        'connector': connector,
+        'connector': make_connector(),
         'headers': {'User-Agent': USER_AGENT},
         'trust_env': True,  # Respect the 'http_proxy' env var
         'timeout': ClientTimeout(connect=60, sock_connect=10, sock_read=10),
@@ -262,7 +288,7 @@ class _DummyResolver(BaseResolver):
 
 class _ResolverDict(_BaseResolverDict):
     def __missing__(self, key: str) -> Resolver:
-        return _DummyResolver  # type: ignore
+        return _DummyResolver
 
 
 async def capture_manager_exc_async(
@@ -294,13 +320,14 @@ class _DummyLock:
 def _with_lock(
     lock_name: str,
     manager_bound: bool = True,
-) -> Callable[[_C], _C]:
-    def outer(coro_fn: _C) -> _C:
-        async def inner(self: Manager, *args: object, **kwargs: object):
-            async with self.locks[f'{id(self)}_{lock_name}' if manager_bound else lock_name]:
+):
+    def outer(coro_fn: _CManager[_P, _T]) -> _CManager[_P, _T]:
+        @wraps(coro_fn)
+        async def inner(self: Manager, *args: _P.args, **kwargs: _P.kwargs):
+            async with self.locks[f'{id(self)}-{lock_name}' if manager_bound else lock_name]:
                 return await coro_fn(self, *args, **kwargs)
 
-        return inner  # type: ignore
+        return inner
 
     return outer
 
@@ -773,11 +800,9 @@ class Manager:
 
         strategies = frozenset({Strategy.default, Strategy.version})
 
-        def pin(
-            defn: Defn, pkg: models.Pkg | None
-        ) -> R.PkgNotInstalled | R.PkgInstalled | R.PkgStrategyUnsupported:
+        def pin(defn: Defn, pkg: models.Pkg | None) -> R.PkgInstalled:
             if not pkg:
-                return R.PkgNotInstalled()
+                raise R.PkgNotInstalled
 
             elif {defn.strategy} <= strategies <= self.resolvers[pkg.source].strategies:
                 self.database.execute(
@@ -796,7 +821,7 @@ class Manager:
                 return R.PkgInstalled(models.Pkg.from_row_mapping(self.database, row_mapping))
 
             else:
-                return R.PkgStrategyUnsupported(Strategy.version)
+                raise R.PkgStrategyUnsupported(Strategy.version)
 
         return {d: await capture_manager_exc_async(t(pin)(d, self.get_pkg(d))) for d in defns}
 
@@ -810,7 +835,7 @@ async def is_outdated() -> tuple[bool, str]:
 
     from . import __version__
 
-    def parse_version(version: str) -> tuple[int, ...]:
+    def parse_version(version: str):
         version_parts = takewhile(lambda p: all(c in '0123456789' for c in p), version.split('.'))
         return tuple(map(int, version_parts))
 
