@@ -290,9 +290,7 @@ class CurseResolver(BaseResolver):
 
     @staticmethod
     def get_alias_from_url(url: URL) -> str | None:
-        if url.host == 'www.wowace.com' and len(url.parts) > 2 and url.parts[1] == 'projects':
-            return url.parts[2].lower()
-        elif (
+        if (
             url.host == 'www.curseforge.com'
             and len(url.parts) > 3
             and url.parts[1:3] == ('wow', 'addons')
@@ -839,7 +837,7 @@ class TukuiResolver(BaseResolver):
 class _GithubRepo(TypedDict):
     name: str  # the repo in user-or-org/repo
     full_name: str  # user-or-org/repo
-    description: str
+    description: str | None
     html_url: str
 
 
@@ -1003,7 +1001,7 @@ class GithubResolver(BaseResolver):
             id=project_metadata['full_name'],
             slug=project_metadata['full_name'].lower(),
             name=project_metadata['name'],
-            description=project_metadata['description'],
+            description=project_metadata['description'] or '',
             url=project_metadata['html_url'],
             download_url=matching_asset['browser_download_url'],
             date_published=release_metadata['published_at'],
