@@ -5,12 +5,11 @@ from functools import partial, reduce
 from itertools import chain, product
 import time
 import typing
-from typing import TYPE_CHECKING, Any, ClassVar, Generic, TypeVar
+from typing import TYPE_CHECKING, Any, TypeVar
 
 from loguru import logger
 from pydantic import BaseModel, Field, validator
-from pydantic.generics import GenericModel
-from typing_extensions import Literal, TypeAlias, TypedDict
+from typing_extensions import Literal, Protocol, TypeAlias, TypedDict
 from yarl import URL
 
 from . import manager
@@ -24,11 +23,10 @@ if TYPE_CHECKING:  # pragma: no cover
     from typing_extensions import NotRequired as N
 
 
-_ImportString: TypeAlias = str
-_Slug: TypeAlias = str
-AuraGroup: TypeAlias = 'Sequence[tuple[Sequence[WeakAura], WagoApiResponse, _ImportString]]'
-
-_TWeakAura = TypeVar('_TWeakAura', bound='WeakAura', covariant=True)
+_TAuras = TypeVar('_TAuras', bound='BaseAuras')
+_Slug = str
+_ImportString = str
+_AuraGroup: TypeAlias = 'Sequence[tuple[Sequence[WeakAura], WagoApiResponse, _ImportString]]'
 
 IMPORT_API_URL = URL('https://data.wago.io/api/raw/encoded')
 
@@ -37,23 +35,21 @@ class BuilderConfig(BaseConfig):
     wago_api_key: typing.Optional[str] = None
 
 
-class Auras(
-    GenericModel,
-    Generic[_TWeakAura],
+class BaseAuras(
+    BaseModel,
     arbitrary_types_allowed=True,
     json_encoders={URL: str},
 ):
-    api_url: ClassVar[URL]
-    filename: ClassVar[str]
-
-    __root__: typing.Dict[_Slug, typing.List[_TWeakAura]]
+    class Meta(Protocol):
+        api_url: URL
+        filename: str
 
     @classmethod
-    def from_lua_table(cls, lua_table: Any) -> Auras[_TWeakAura]:
+    def from_lua_table(cls: type[_TAuras], lua_table: Any) -> _TAuras:
         raise NotImplementedError
 
 
-def _merge_auras(auras: Iterable[Auras[WeakAura]]) -> dict[type, Auras[WeakAura]]:
+def _merge_auras(auras: Iterable[_TAuras]) -> dict[type, _TAuras]:
     "Merge auras of the same type."
     return {
         t: t(__root__=reduce(lambda a, b: {**a, **b}, (i.__root__ for i in a)))
@@ -87,9 +83,12 @@ class WeakAura(
         return value
 
 
-class WeakAuras(Auras[WeakAura]):
-    api_url = URL('https://data.wago.io/api/check/weakauras')
-    filename = 'WeakAuras.lua'
+class WeakAuras(BaseAuras):
+    class Meta:
+        api_url = URL('https://data.wago.io/api/check/weakauras')
+        filename = 'WeakAuras.lua'
+
+    __root__: typing.Dict[_Slug, typing.List[WeakAura]]
 
     @classmethod
     def from_lua_table(cls, lua_table: Any) -> WeakAuras:
@@ -105,9 +104,12 @@ class Plateroo(WeakAura):
     uid = ''
 
 
-class Plateroos(Auras[Plateroo]):
-    api_url = URL('https://data.wago.io/api/check/plater')
-    filename = 'Plater.lua'
+class Plateroos(BaseAuras):
+    class Meta:
+        api_url = URL('https://data.wago.io/api/check/plater')
+        filename = 'Plater.lua'
+
+    __root__: typing.Dict[_Slug, typing.List[Plateroo]]
 
     @classmethod
     def from_lua_table(cls, lua_table: Any) -> Plateroos:
@@ -161,21 +163,21 @@ class WaCompanionBuilder:
         self.checksum_txt_path = output_folder / 'checksum.txt'
 
     @staticmethod
-    def extract_auras(model: type[Auras[WeakAura]], source: str) -> Auras[WeakAura]:
+    def extract_auras(model: type[_TAuras], source: str) -> _TAuras:
         from ._custom_slpp import SLPP
 
         source_after_assignment = source[source.find('=') + 1 :]
         lua_table = SLPP(source_after_assignment).decode()
         return model.from_lua_table(lua_table)
 
-    def extract_installed_auras(self) -> Iterator[Auras[WeakAura]]:
+    def extract_installed_auras(self) -> Iterator[WeakAuras | Plateroos]:
         flavour_root = self.manager.config.addon_dir.parents[1]
         saved_vars_of_every_account = flavour_root.glob('WTF/Account/*/SavedVariables')
         for saved_vars, model in product(
             saved_vars_of_every_account,
             [WeakAuras, Plateroos],
         ):
-            file = saved_vars / model.filename
+            file = saved_vars / model.Meta.filename
             if not file.exists():
                 logger.info(f'{file} not found')
             else:
@@ -222,11 +224,11 @@ class WaCompanionBuilder:
             request_extra={'headers': {'api-key': self.builder_config.wago_api_key or ''}},
         )
 
-    async def get_remote_auras(self, auras: Auras[WeakAura]) -> AuraGroup:
+    async def get_remote_auras(self, auras: BaseAuras) -> _AuraGroup:
         if not auras.__root__:
             return []
 
-        metadata = await self._fetch_wago_metadata(auras.api_url, auras.__root__)
+        metadata = await self._fetch_wago_metadata(auras.Meta.api_url, auras.__root__)
         import_strings = await gather(self._fetch_wago_import_string(r) for r in metadata)
         return [(auras.__root__[r['slug']], r, i) for r, i in zip(metadata, import_strings)]
 
@@ -247,7 +249,9 @@ class WaCompanionBuilder:
         elif game_flavour is Flavour.burning_crusade_classic:
             return '20502'
 
-    def _generate_addon(self, auras: Iterable[tuple[type[Auras[WeakAura]], AuraGroup]]) -> None:
+    def _generate_addon(
+        self, auras: Iterable[tuple[type[WeakAuras | Plateroos], _AuraGroup]]
+    ) -> None:
         from importlib.resources import read_text
         from zipfile import ZipFile, ZipInfo
 
