@@ -1,5 +1,8 @@
+from __future__ import annotations
+
 from functools import partial
 import json
+import shutil
 from textwrap import dedent
 
 from click.testing import CliRunner
@@ -10,7 +13,7 @@ import pytest
 
 from instawow import __version__
 from instawow.cli import main
-from instawow.config import Flavour
+from instawow.config import Config, Flavour
 from instawow.manager import Manager
 from instawow.models import PkgList
 
@@ -24,7 +27,7 @@ def feed_pt():
 
 
 @pytest.fixture
-def run(monkeypatch, event_loop, iw_config, iw_web_client):
+def run(monkeypatch: pytest.MonkeyPatch, event_loop, iw_config: Config, iw_web_client):
     def runner(awaitable):
         Manager.contextualise(web_client=iw_web_client)
         return event_loop.run_until_complete(awaitable)
@@ -35,13 +38,13 @@ def run(monkeypatch, event_loop, iw_config, iw_web_client):
 
 
 @pytest.fixture
-def molinari_and_run(run):
+def install_molinari_and_run(run):
     run('install curse:molinari')
     yield run
 
 
 @pytest.fixture
-def faux_molinari_and_run(iw_config, run):
+def faux_install_molinari_and_run(iw_config: Config, run):
     molinari = iw_config.addon_dir / 'Molinari'
     molinari.mkdir()
     (molinari / 'Molinari.toc').write_text(
@@ -53,77 +56,38 @@ def faux_molinari_and_run(iw_config, run):
     yield run
 
 
-def test_valid_curse_pkg_lifecycle(iw_config, run):
-    assert run('install curse:molinari').output.startswith('✓ curse:molinari\n  installed')
-    assert (
-        run('install curse:molinari').output == '✗ curse:molinari\n  package already installed\n'
-    )
-    assert run('update curse:molinari').output == '✗ curse:molinari\n  package is up to date\n'
-    assert run('remove curse:molinari').output == '✓ curse:molinari\n  removed\n'
-    assert run('update curse:molinari').output == '✗ curse:molinari\n  package is not installed\n'
-    assert run('remove curse:molinari').output == '✗ curse:molinari\n  package is not installed\n'
-
-
-def test_valid_tukui_pkg_lifecycle(iw_config, run):
-    assert run('install tukui:1').output.startswith('✓ tukui:1\n  installed')
-    assert run('install tukui:1').output == '✗ tukui:1\n  package already installed\n'
-    assert run('update tukui:1').output == '✗ tukui:1\n  package is up to date\n'
-    assert run('remove tukui:1').output == '✓ tukui:1\n  removed\n'
-    assert run('update tukui:1').output == '✗ tukui:1\n  package is not installed\n'
-    assert run('remove tukui:1').output == '✗ tukui:1\n  package is not installed\n'
-    if iw_config.game_flavour is Flavour.retail:
-        assert run('install tukui:-1').output.startswith('✓ tukui:-1\n  installed')
-        assert run('install tukui:-1').output == '✗ tukui:-1\n  package already installed\n'
-        assert run('update tukui:-1').output == '✗ tukui:-1\n  package is up to date\n'
-        assert run('remove tukui:-1').output == '✓ tukui:-1\n  removed\n'
+@pytest.fixture
+def molinari_version_suffix(iw_config: Config):
+    if iw_config.game_flavour is Flavour.vanilla_classic:
+        return '-classic'
+    if iw_config.game_flavour is Flavour.burning_crusade_classic:
+        return '-bcc'
     else:
-        assert run('install tukui:-1').output == '✗ tukui:-1\n  package does not exist\n'
-    assert run('update tukui:-1').output == '✗ tukui:-1\n  package is not installed\n'
-    assert run('remove tukui:-1').output == '✗ tukui:-1\n  package is not installed\n'
+        return ''
 
 
-def test_valid_wowi_pkg_lifecycle(run):
-    assert run('install wowi:13188-molinari').output.startswith(
-        '✓ wowi:13188-molinari\n  installed'
-    )
-    assert (
-        run('install wowi:13188-molinari').output
-        == '✗ wowi:13188-molinari\n  package already installed\n'
-    )
-    assert (
-        run('update wowi:13188-molinari').output
-        == '✗ wowi:13188-molinari\n  package is up to date\n'
-    )
-    assert run('remove wowi:13188-molinari').output == '✓ wowi:13188-molinari\n  removed\n'
-    assert (
-        run('update wowi:13188-molinari').output
-        == '✗ wowi:13188-molinari\n  package is not installed\n'
-    )
-    assert (
-        run('remove wowi:13188-molinari').output
-        == '✗ wowi:13188-molinari\n  package is not installed\n'
-    )
+@pytest.mark.parametrize('alias', ['curse:molinari', 'wowi:13188-molinari', 'tukui:1'])
+def test_valid_pkg_lifecycle(run, alias: str):
+    assert run(f'install {alias}').output.startswith(f'✓ {alias}\n  installed')
+    assert run(f'install {alias}').output == f'✗ {alias}\n  package already installed\n'
+    assert run(f'update {alias}').output == f'✗ {alias}\n  package is up to date\n'
+    assert run(f'remove {alias}').output == f'✓ {alias}\n  removed\n'
+    assert run(f'update {alias}').output == f'✗ {alias}\n  package is not installed\n'
+    assert run(f'remove {alias}').output == f'✗ {alias}\n  package is not installed\n'
 
 
-def test_invalid_source_lifecycle(run):
-    assert run('install foo:bar').output == '✗ foo:bar\n  package source is invalid\n'
-    assert run('update foo:bar').output == '✗ foo:bar\n  package is not installed\n'
-    assert run('remove foo:bar').output == '✗ foo:bar\n  package is not installed\n'
+@pytest.mark.parametrize('alias', ['curse:gargantuan-wigs'])
+def test_invalid_alias_pkg_lifecycle(run, alias: str):
+    assert run(f'install {alias}').output == f'✗ {alias}\n  package does not exist\n'
+    assert run(f'update {alias}').output == f'✗ {alias}\n  package is not installed\n'
+    assert run(f'remove {alias}').output == f'✗ {alias}\n  package is not installed\n'
 
 
-def test_nonexistent_addon_alias_lifecycle(run):
-    assert (
-        run('install curse:gargantuan-wigs').output
-        == '✗ curse:gargantuan-wigs\n  package does not exist\n'
-    )
-    assert (
-        run('update curse:gargantuan-wigs').output
-        == '✗ curse:gargantuan-wigs\n  package is not installed\n'
-    )
-    assert (
-        run('remove curse:gargantuan-wigs').output
-        == '✗ curse:gargantuan-wigs\n  package is not installed\n'
-    )
+@pytest.mark.parametrize('alias', ['foo:bar'])
+def test_invalid_source_pkg_lifecycle(run, alias: str):
+    assert run(f'install {alias}').output == f'✗ {alias}\n  package source is invalid\n'
+    assert run(f'update {alias}').output == f'✗ {alias}\n  package is not installed\n'
+    assert run(f'remove {alias}').output == f'✗ {alias}\n  package is not installed\n'
 
 
 def test_reconciled_folder_conflict_on_install(run):
@@ -135,7 +99,7 @@ def test_reconciled_folder_conflict_on_install(run):
     )
 
 
-def test_unreconciled_folder_conflict_on_install(iw_config, run):
+def test_unreconciled_folder_conflict_on_install(iw_config: Config, run):
     iw_config.addon_dir.joinpath('Molinari').mkdir()
     assert (
         run('install curse:molinari').output
@@ -146,9 +110,9 @@ def test_unreconciled_folder_conflict_on_install(iw_config, run):
     )
 
 
-def test_keep_folders_on_remove(iw_config, molinari_and_run):
+def test_keep_folders_on_remove(iw_config: Config, install_molinari_and_run):
     assert (
-        molinari_and_run('remove --keep-folders curse:molinari').output
+        install_molinari_and_run('remove --keep-folders curse:molinari').output
         == '✓ curse:molinari\n  removed\n'
     )
     assert iw_config.addon_dir.joinpath('Molinari').is_dir()
@@ -157,10 +121,6 @@ def test_keep_folders_on_remove(iw_config, molinari_and_run):
 def test_install_with_curse_alias(run):
     assert run('install curse:molinari').output.startswith('✓ curse:molinari\n  installed')
     assert run('install curse:20338').output == '✗ curse:20338\n  package already installed\n'
-    assert (
-        run('install https://www.wowace.com/projects/molinari').output
-        == '✗ curse:molinari\n  package already installed\n'
-    )
     assert (
         run('install https://www.curseforge.com/wow/addons/molinari').output
         == '✗ curse:molinari\n  package already installed\n'
@@ -171,7 +131,7 @@ def test_install_with_curse_alias(run):
     )
 
 
-def test_install_with_tukui_alias(iw_config, run):
+def test_install_with_tukui_alias(iw_config: Config, run):
     if iw_config.game_flavour is Flavour.retail:
         assert run('install tukui:-1').output.startswith('✓ tukui:-1\n  installed')
         assert run('install tukui:tukui').output == '✗ tukui:tukui\n  package already installed\n'
@@ -238,7 +198,7 @@ def test_install_with_github_alias(run):
     )
 
 
-def test_version_strategy_lifecycle(iw_config, run):
+def test_version_strategy_lifecycle(iw_config: Config, run):
     assert run('install curse:molinari').output.startswith(
         '✓ curse:molinari\n  installed 90100.79-Release'
     )
@@ -261,7 +221,7 @@ def test_version_strategy_lifecycle(iw_config, run):
     assert run('remove curse:molinari').output == '✓ curse:molinari\n  removed\n'
 
 
-def test_install_options(iw_config, run):
+def test_install_options(run, molinari_version_suffix):
     assert run(
         'install'
         ' curse:molinari'
@@ -270,7 +230,7 @@ def test_install_options(iw_config, run):
     ).output == dedent(
         f'''\
         ✓ curse:molinari
-          installed 90100.79-Release{"-classic" if iw_config.game_flavour is Flavour.vanilla_classic else ""}
+          installed 90100.79-Release{molinari_version_suffix}
         ✗ curse:molinari
           package folders conflict with installed package Molinari
             (curse:20338)
@@ -301,13 +261,13 @@ def test_install_option_order_is_respected(run):
     )
 
 
-def test_install_argument_is_not_required(iw_config, run):
+def test_install_argument_is_not_required(run, molinari_version_suffix):
     assert run(
         'install -s latest curse:molinari --version 80000.57-Release curse:molinari'
     ).output == dedent(
         f'''\
         ✓ curse:molinari
-          installed 90100.79-Release{"-classic" if iw_config.game_flavour is Flavour.vanilla_classic else ""}
+          installed 90100.79-Release{molinari_version_suffix}
         ✗ curse:molinari
           package folders conflict with installed package Molinari
             (curse:20338)
@@ -315,7 +275,7 @@ def test_install_argument_is_not_required(iw_config, run):
     )
 
 
-def test_configure__display_active_profile(iw_config, run):
+def test_configure__display_active_profile(iw_config: Config, run):
     assert run('configure --active').output == iw_config.json(indent=2) + '\n'
 
 
@@ -327,7 +287,7 @@ def test_configure__create_new_profile(feed_pt, iw_config, run):
     )
 
 
-def test_configure__create_new_profile_promptless(monkeypatch, iw_config, run):
+def test_configure__create_new_profile_promptless(monkeypatch: pytest.MonkeyPatch, iw_config, run):
     monkeypatch.setenv('INSTAWOW_ADDON_DIR', str(iw_config.addon_dir))
     monkeypatch.setenv('INSTAWOW_GAME_FLAVOUR', iw_config.game_flavour.value)
     assert (
@@ -361,7 +321,7 @@ def test_rollback__single_version(run):
     )
 
 
-def test_rollback__multiple_versions(feed_pt, iw_config, run):
+def test_rollback__multiple_versions(feed_pt, run, molinari_version_suffix):
     assert run('install --version 80000.57-Release curse:molinari').exit_code == 0
     assert run('remove curse:molinari').exit_code == 0
     assert run('install curse:molinari').exit_code == 0
@@ -369,25 +329,25 @@ def test_rollback__multiple_versions(feed_pt, iw_config, run):
     assert run('rollback curse:molinari').output == dedent(
         f'''\
         ✓ curse:molinari
-          updated 90100.79-Release{"-classic" if iw_config.game_flavour is Flavour.vanilla_classic else ""} to 80000.57-Release
+          updated 90100.79-Release{molinari_version_suffix} to 80000.57-Release
         '''
     )
 
 
-def test_rollback__multiple_versions_promptless(iw_config, run):
+def test_rollback__multiple_versions_promptless(run, molinari_version_suffix):
     assert run('install --version 80000.57-Release curse:molinari').exit_code == 0
     assert run('remove curse:molinari').exit_code == 0
     assert run('install curse:molinari').exit_code == 0
     assert run('rollback --version 80000.57-Release curse:molinari').output == dedent(
         f'''\
         ✓ curse:molinari
-          updated 90100.79-Release{"-classic" if iw_config.game_flavour is Flavour.vanilla_classic else ""} to 80000.57-Release
+          updated 90100.79-Release{molinari_version_suffix} to 80000.57-Release
         '''
     )
 
 
 @pytest.mark.parametrize('options', ['', '--undo'])
-def test_rollback__rollback_multiple_versions(feed_pt, iw_config, run, options):
+def test_rollback__rollback_multiple_versions(feed_pt, run, molinari_version_suffix, options):
     assert run('install curse:molinari').exit_code == 0
     assert run('remove curse:molinari').exit_code == 0
     assert run('install --version 80000.57-Release curse:molinari').exit_code == 0
@@ -395,7 +355,7 @@ def test_rollback__rollback_multiple_versions(feed_pt, iw_config, run, options):
     assert run(f'rollback {options} curse:molinari').output == dedent(
         f'''\
         ✓ curse:molinari
-          updated 80000.57-Release to 90100.79-Release{"-classic" if iw_config.game_flavour is Flavour.vanilla_classic else ""}
+          updated 80000.57-Release to 90100.79-Release{molinari_version_suffix}
         '''
     )
 
@@ -406,8 +366,8 @@ def test_rollback__cannot_use_version_with_undo(run):
     assert 'Cannot use "--version" and "--undo" together' in result.output
 
 
-def test_reconcile__list_unreconciled(faux_molinari_and_run):
-    assert faux_molinari_and_run('reconcile --list-unreconciled').output == (
+def test_reconcile__list_unreconciled(faux_install_molinari_and_run):
+    assert faux_install_molinari_and_run('reconcile --list-unreconciled').output == (
         # fmt: off
         'unreconciled\n'
         '------------\n'
@@ -416,27 +376,29 @@ def test_reconcile__list_unreconciled(faux_molinari_and_run):
     )
 
 
-def test_reconcile__auto_reconcile(iw_config, faux_molinari_and_run):
-    assert faux_molinari_and_run('reconcile --auto').output == dedent(
+def test_reconcile__auto_reconcile(faux_install_molinari_and_run, molinari_version_suffix):
+    assert faux_install_molinari_and_run('reconcile --auto').output == dedent(
         f'''\
         ✓ curse:molinari
-          installed 90100.79-Release{"-classic" if iw_config.game_flavour is Flavour.vanilla_classic else ""}
+          installed 90100.79-Release{molinari_version_suffix}
         '''
     )
 
 
-def test_reconcile__abort_interactive_reconciliation(feed_pt, faux_molinari_and_run):
+def test_reconcile__abort_interactive_reconciliation(feed_pt, faux_install_molinari_and_run):
     feed_pt('\x03')  # ^C
-    assert faux_molinari_and_run('reconcile').output.endswith('Aborted!\n')
+    assert faux_install_molinari_and_run('reconcile').output.endswith('Aborted!\n')
 
 
-def test_reconcile__complete_interactive_reconciliation(feed_pt, iw_config, faux_molinari_and_run):
+def test_reconcile__complete_interactive_reconciliation(
+    feed_pt, faux_install_molinari_and_run, molinari_version_suffix
+):
     feed_pt('\r\r')
-    assert faux_molinari_and_run('reconcile').output.endswith(
+    assert faux_install_molinari_and_run('reconcile').output.endswith(
         dedent(
             f'''\
             ✓ curse:molinari
-              installed 90100.79-Release{"-classic" if iw_config.game_flavour is Flavour.vanilla_classic else ""}
+              installed 90100.79-Release{molinari_version_suffix}
             '''
         )
     )
@@ -460,48 +422,55 @@ def test_search__exit_after_selection(feed_pt, run):
     assert run('search molinari').output == ''
 
 
-def test_search__install_one(feed_pt, iw_config, run):
+def test_search__install_one(feed_pt, run, molinari_version_suffix):
     feed_pt(' \r\r')  # space, enter, enter
     assert run('search molinari --source curse').output == dedent(
         f'''\
         ✓ curse:molinari
-          installed 90100.79-Release{"-classic" if iw_config.game_flavour is Flavour.vanilla_classic else ""}
+          installed 90100.79-Release{molinari_version_suffix}
         '''
     )
 
 
-def test_search__install_multiple_conflicting(feed_pt, iw_config, run):
+def test_search__install_multiple_conflicting(feed_pt, run):
     feed_pt(' \x1b[B \r\r')  # space, arrow down, space, enter, enter
-    assert run('search molinari').output in {
-        dedent(
-            f'''\
-            ✓ curse:molinari
-              installed 90100.79-Release{"-classic" if iw_config.game_flavour is Flavour.vanilla_classic else ""}
-            ✗ wowi:13188-molinari
-              package folders conflict with installed package Molinari
-                (curse:20338)
-            '''
-        ),
-        dedent(
-            f'''\
-            ✓ wowi:13188-molinari
-              installed 90100.79-Release
-            ✗ curse:molinari
-              package folders conflict with installed package Molinari
-                (wowi:13188)
-            '''
-        ),
-    }
-
-
-def test_changelog_output_with_arg(molinari_and_run):
-    assert molinari_and_run('view-changelog curse:molinari').output.startswith(
-        '<h3>Changes in 90100.79-Release:</h3>'
+    assert run('search molinari').output == dedent(
+        f'''\
+        ✓ wowi:13188-molinari
+          installed 90100.79-Release
+        ✗ curse:molinari
+          package folders conflict with installed package Molinari
+            (wowi:13188)
+        '''
     )
 
 
-def test_argless_changelog_output(molinari_and_run):
-    assert molinari_and_run('view-changelog').output.startswith(
+def test_changelog_output(install_molinari_and_run):
+    output = (
+        'Changes in 90100.79-Release:'
+        if shutil.which('pandoc')
+        else '<h3>Changes in 90100.79-Release:</h3>'
+    )
+    assert install_molinari_and_run('view-changelog curse:molinari').output.startswith(output)
+
+
+def test_changelog_output_no_convert(install_molinari_and_run):
+    assert install_molinari_and_run(
+        'view-changelog --no-convert curse:molinari'
+    ).output.startswith('<h3>Changes in 90100.79-Release:</h3>')
+
+
+def test_argless_changelog_output(install_molinari_and_run):
+    output = (
+        'curse:molinari:\n  Changes in 90100.79-Release:'
+        if shutil.which('pandoc')
+        else 'curse:molinari:\n  <h3>Changes in 90100.79-Release:</h3>'
+    )
+    assert install_molinari_and_run('view-changelog').output.startswith(output)
+
+
+def test_argless_changelog_output_no_convert(install_molinari_and_run):
+    assert install_molinari_and_run('view-changelog --no-convert').output.startswith(
         'curse:molinari:\n  <h3>Changes in 90100.79-Release:</h3>'
     )
 
@@ -515,21 +484,23 @@ def test_argless_changelog_output(molinari_and_run):
         ('reveal foo', 1),
     ],
 )
-def test_exit_codes_with_substr_match(monkeypatch, molinari_and_run, command, exit_code):
-    monkeypatch.setattr('click.launch', lambda url, wait=..., locate=...: ...)
-    assert molinari_and_run(command).exit_code == exit_code
+def test_exit_codes_with_substr_match(
+    monkeypatch: pytest.MonkeyPatch, install_molinari_and_run, command, exit_code
+):
+    monkeypatch.setattr('click.launch', lambda *a, **k: ...)
+    assert install_molinari_and_run(command).exit_code == exit_code
 
 
-def test_can_list_with_substr_match(molinari_and_run):
-    assert molinari_and_run('list mol').output == 'curse:molinari\n'
-    assert molinari_and_run('list foo').output == ''
-    assert molinari_and_run('list -f detailed mol').output.startswith('curse:molinari')
-    (molinari,) = json.loads(molinari_and_run('list -f json mol').output)
+def test_can_list_with_substr_match(install_molinari_and_run):
+    assert install_molinari_and_run('list mol').output == 'curse:molinari\n'
+    assert install_molinari_and_run('list foo').output == ''
+    assert install_molinari_and_run('list -f detailed mol').output.startswith('curse:molinari')
+    (molinari,) = json.loads(install_molinari_and_run('list -f json mol').output)
     assert (molinari['source'], molinari['slug']) == ('curse', 'molinari')
 
 
-def test_json_export(iw_config, molinari_and_run):
-    output = molinari_and_run('list -f json').output
+def test_json_export(install_molinari_and_run):
+    output = install_molinari_and_run('list -f json').output
     assert PkgList.parse_raw(output).__root__[0].name == 'Molinari'
 
 
